FigmaVariable class

Constructors

FigmaVariable({required String id, required String name, required String resolvedType, required Map<String, dynamic> valuesByMode, required String variableCollectionId})
FigmaVariable.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
resolvedType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valuesByMode Map<String, dynamic>
final
variableCollectionId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited